<?php

defined ('_JEXEC') or die('Restricted access');

/**
 * Plugin providing regexp function for VM Shipping by Rules
 *
 * @subpackage Plugins - VmShipmentRules
 * @copyright Copyright (C) 2014 Reinhold Kainhofer, office@open-tools.net
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 * VirtueMart is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See administrator/components/com_virtuemart/COPYRIGHT.php for copyright notices and details.
 *
 * http://open-tools.net/
 *
 */
if (!class_exists ('VmPlugin')) {
	require(JPATH_VM_PLUGINS . DS . 'vmplugin.php');
}

/** This plugin provides the following RegExp-related functions to the shipping by rules plugin:
 *   - RegExpMatch(pattern, value)   - returns whether the value matches the expression (true/false)
 *   - RegExpMatches(pattern, value) - returns an array of all matches of regexp within the value (array)
 *   - RegExpReplace(pattern, value) - preforms a regexp replacement on the value, returns the resulting string (string)
 *   - RegExpSplit(pattern, value)   - splits value using the regexp as delimiter, returns array of all substrings (excluding the delimiter) (array)
 *   - RegExpFilter(pattern, array)  - returns all members of the array that match the regexp (array)
 */

/** Extension plugin for the "Shipping by Rules" shipping plugin for VirtueMart
 */
class plgVmShipmentRulesRegexp extends VmPlugin {
	/** Register the regexp functions... */
	function onVmShippingRulesRegisterCustomFunctions() {
		return array(
			'RegExpMatch'   => array('plgVmShipmentRulesRegexp', 'rules_regexp_match'),
			'RegExpMatches' => array('plgVmShipmentRulesRegexp', 'rules_regexp_matches'),
			'RegExpReplace' => array('plgVmShipmentRulesRegexp', 'rules_regexp_replace'),
			'RegExpSplit'   => array('plgVmShipmentRulesRegexp', 'rules_regexp_split'),
			'RegExpFilter'  => array('plgVmShipmentRulesRegexp', 'rules_regexp_filter'),
		);
	}

	/** RegExpMatch(RegExp, string) => return true/false */
	static function rules_regexp_match($args, $rule) {
		if (count($args)<2) {
			JFactory::getApplication()->enqueueMessage(JText::sprintf('VMSHIPMENT_RULES_REGEXP_ARGS', "RegExpMatch", "two",  "RegExpMatch(pattern, string)", htmlentities($rule->rulestring)), 'error');
			return false;
		}
		return preg_match($args[0], $args[1]);
	}

	/** RegExpMatches(RegExp, string) => returns an array of all matches of regexp in the given string */
	static function rules_regexp_matches($args, $rule) {
		if (count($args)<2) {
			JFactory::getApplication()->enqueueMessage(JText::sprintf('VMSHIPMENT_RULES_REGEXP_ARGS', "RegExpMatches", "two",  "RegExpMatches(pattern, string)",  htmlentities($rule->rulestring)), 'error');
			return false;
		}
		preg_match_all($args[0], $args[1], $matches);
		return $matches[0];
	}

	/** RegExpReplace(RegExp, string) => preforms a regexp replacement on the value, returns the resulting string */
	static function rules_regexp_replace($args, $rule) {
		if (count($args)<3) {
			JFactory::getApplication()->enqueueMessage(JText::sprintf('VMSHIPMENT_RULES_REGEXP_ARGS', "RegExpReplace", "three", "RegExpReplace(pattern, replacement, string)",  htmlentities($rule->rulestring)), 'error');
			return false;
		}
		return preg_replace($args[0], $args[1], $args[2]);
	}

	/** RegExpSplit(RegExp, string) => preforms a regexp replacement on the value, returns the resulting string */
	static function rules_regexp_split($args, $rule) {
		if (count($args)<2) {
			JFactory::getApplication()->enqueueMessage(JText::sprintf('VMSHIPMENT_RULES_REGEXP_ARGS', "RegExpSplit", "two", "RegExpSplit(pattern, string)",  htmlentities($rule->rulestring)), 'error');
			return false;
		}
		return preg_split($args[0], $args[1]);
	}

	/** RegExpFilter(RegExp, array) => returns all entries of the array that match the regexp pattern */
	static function rules_regexp_filter($args, $rule) {
		if (count($args)<2) {
			JFactory::getApplication()->enqueueMessage(JText::sprintf('VMSHIPMENT_RULES_REGEXP_ARGS', "RegExpFilter", "two", "RegExpFilter(pattern, array)",  htmlentities($rule->rulestring)), 'error');
			return false;
		}
		return preg_grep($args[0], $args[1]);
	}
}

// No closing tag
